#
# spec file for package libdmapsharing
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2010 Dominique Leuenberger, Amsterdam, Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define majorver 4.0
%define soname 4_0
%define sover 3

Name:           libdmapsharing
Version:        3.9.13
Release:        1.1
Summary:        Library implementing the Digital Media Access Protocol family
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            https://www.flyn.org/projects/libdmapsharing/
Source0:        %{url}/%{name}-%{version}.tar.gz

BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(avahi-client) >= 0.6
BuildRequires:  pkgconfig(avahi-glib) >= 0.6
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(glib-2.0) >= 2.36
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(libsoup-3.0)

%description
Libdmapsharing is a library you may use to access, share and control the
playback of media content using DMAP (DAAP, DPAP & DACP). Libdmapsharing
also detects audio AirPlay services; coupled with the AirPlay support
in PulseAudio or GStreamer, this can allow an application to stream audio
to an AirPlay device. The DMAP family of protocols are used by products
such as Apple iTunes, Apple iPhoto, and the Roku SoundBridge family to
share media such as music and photos.

%package -n libdmapsharing-%{soname}-%{sover}
Summary:        Library implementing the Digital Media Access Protocol family
Group:          System/Libraries

%description -n libdmapsharing-%{soname}-%{sover}
Libdmapsharing is a library you may use to access, share and control the
playback of media content using DMAP (DAAP, DPAP & DACP). Libdmapsharing
also detects audio AirPlay services; coupled with the AirPlay support
in PulseAudio or GStreamer, this can allow an application to stream audio
to an AirPlay device. The DMAP family of protocols are used by products
such as Apple iTunes, Apple iPhoto, and the Roku SoundBridge family to
share media such as music and photos.

%package -n typelib-1_0-Dmap-4_0
Summary:        Typelib for libdmapsharing
Group:          Productivity/Multimedia/Other

%description -n typelib-1_0-Dmap-4_0
Libdmapsharing is a library you may use to access, share and control the
playback of media content using DMAP (DAAP, DPAP & DACP). Libdmapsharing
also detects audio AirPlay services; coupled with the AirPlay support
in PulseAudio or GStreamer, this can allow an application to stream audio
to an AirPlay device. The DMAP family of protocols are used by products
such as Apple iTunes, Apple iPhoto, and the Roku SoundBridge family to
share media such as music and photos.

%package devel
Summary:        Library implementing the DMAP family of protocols - Development Files
Group:          Development/Languages/C and C++
Requires:       libdmapsharing-%{soname}-%{sover} = %{version}
Requires:       typelib-1_0-Dmap-4_0 = %{version}

%description devel
Libdmapsharing is a library you may use to access, share and control the
playback of media content using DMAP (DAAP, DPAP & DACP). Libdmapsharing
also detects audio AirPlay services; coupled with the AirPlay support
in PulseAudio or GStreamer, this can allow an application to stream audio
to an AirPlay device. The DMAP family of protocols are used by products
such as Apple iTunes, Apple iPhoto, and the Roku SoundBridge family to
share media such as music and photos.

This package contains development files for libdmapsharing.

%prep
%autosetup -p1

%build
%configure \
	--disable-static \
	--disable-tests \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libdmapsharing-%{soname}-%{sover} -p /sbin/ldconfig
%postun -n libdmapsharing-%{soname}-%{sover} -p /sbin/ldconfig

%files -n libdmapsharing-%{soname}-%{sover}
%license COPYING
%doc AUTHORS ChangeLog README
%{_libdir}/libdmapsharing-%{majorver}.so.%{sover}*

%files -n typelib-1_0-Dmap-4_0
%{_libdir}/girepository-1.0/Dmap-4.0.typelib

%files devel
%{_datadir}/gtk-doc/html/libdmapsharing-%{majorver}/
%{_datadir}/vala/vapi/libdmapsharing-%{majorver}.vapi
%{_datadir}/gir-1.0/Dmap-4.0.gir
%{_includedir}/libdmapsharing-%{majorver}/
%{_libdir}/libdmapsharing-%{majorver}.so
%{_libdir}/pkgconfig/libdmapsharing-%{majorver}.pc

%changelog
* Wed Oct  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.9.13:
  + doc/Makefile.am: add human-written XML files to EXTRA_DIST
  + Fix Vala tests
  + Use g-ir-scanner output as input to vapigen
  + configure.ac: Don't force CFLAGS=-O2
  + Make use of pedansee-conf-gobject
* Tue May  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.9.12:
  + Initialize a value that might not be initialized by
    g_object_get
  + libdmapsharing/Makefile.am:
  - rename check target to check-local
  - remove dmap-enums.h from maintained_headers
  - avoid cyclic dependencies when building enums
  - simplify use of glib-mkenums after experimenting with FreeBSD
  - drop use of patsubst, which is not POSIX
  + Update GTK-Doc markup to include summaries
  + dmap-structure.c: replace g_memdup, which glib2 replaced with
    g_memdup2
  + Replace deprecated portions of autotools files
* Mon Mar 13 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.9.11:
  + Migrate to libsoup3.
  + Remove extraneous #includes.
  + Round of cleanup.
  + vala-dmap-db.vala: fix object ownership issue.
- Replace pkgconfig(libsoup-2.4) with pkgconfig(libsoup-3.0)
  following upstream changes.
* Mon Dec 19 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: there is no known consumer of the -32bit
  package.
* Sat Sep  5 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.9.10:
  + No upstream changes/changelog/NEWS provided, please see git-log
    at https://gitlab.gnome.org/GNOME/libdmapsharing
- Pass disable-static to configure, do not build static lib.
- Add new optional pkgconfig(gobject-introspection-1.0)
  BuildRequires, build introspection support.
- Package new introspection subpackage.
* Thu Sep 26 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to 3.9.7:
  + No upstream changes/changelog/NEWS provided, please see git-log
    at https://gitlab.gnome.org/GNOME/libdmapsharing
- Drop new_vala_build.patch: Fixed upstream.
- Disable build of tests, via passing --disable-tests to configure
  as they currently fails to build, and it allows us to drop
  pkgconfig(gtk+-2.0) BuildRequires.
- Add majorver, soname and sover defines and set them to current
  values, ease future version updates that include so* changes.
- Align with what configure checks for: Add  pkgconfig(glib-2.0)
  and pkgconfig(gthread-2.0) BuildRequires, and drop
  pkgconfig(gio-2.0) BuildRequires.
- Run spec-cleaner, modernize spec.
* Tue Sep 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add missing pkgconfig(avahi-client) and pkgconfig(gtk+-2.0)
  BuildRequires previously pulled in by avahi.
* Fri Apr 19 2019 Max Lin <mlin@suse.com>
- Fix build with vala >= 0.43
  * Add new_vala_build.patch carry from
    https://gitlab.gnome.org/GNOME/libdmapsharing/issues/7
* Thu Jun 22 2017 zaitor@opensuse.org
- Update to version 2.9.38:
  + After failing to get preferred port, try both IPV4 and IPV6.
  + Fix bad error handling on soup_server_get_uris (Clang
    scan-build).
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 2.9.37:
  + Use g_new0 (bgo#773400).
  + Do not use literal "VERSION"; use VERSION macro (bgo#773480).
  + Remove memory failure check (bgo#755210).
- Changes from version 2.9.36:
  + Allow explicit disable of libcheck at configure time.
- Changes from version 2.9.35:
  + tests: Fix compilation due to wrong formats.
* Mon Feb 29 2016 zaitor@opensuse.org
- Update to version 2.9.34:
  + Move g_object_unref of server inside conditional.
  + Remove extra g_object_unref in dacp-share.c.
  + Initialize the share_bitwise_t share member.
- Changes from version 2.9.33:
  + Use soup_session_new() instead of deprecated
    soup_session_new_async().
  + Always set base URI path.
  + Use new SoupServer API to create DMAPShare server.
  + Require libsoup 2.48.0.
  + Add to dmap-mdns-browser-dnssd.c the ability to lookup host
    name using mDNS.
  + Fix compile error.
  + First pass cleaning up dmap-mdns-browser-dnssd.c.
  + dns-sd browser: extract name out of, e.g.,
    Foo\032Bar._daap._tcp.local.
  + Set GError when DNSServiceBrowse fails.
* Mon Dec  7 2015 jengelh@inai.de
- Summary and RPM group update
* Mon Nov 23 2015 mpluskal@suse.com
- Update to 2.9.32
  * Small fix for dmap_mdns_browser_start
- Make building more verbose
* Fri Jul 10 2015 zaitor@opensuse.org
- Update to version 2.9.31:
  + Update some Vala-related files.
  + Fix two errors identified by Coverity (bgo#749886).
  + Update libdmapsharing-3.0-docs.xml.
  + Use --pkg gio-2.0, not --pkg glib-2.0 for Vala.
- Replace pkgconfig(glib-2.0) for pkgconfig(gio-2.0) BuildRequires
  following upstream changes.
* Sat Mar 21 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Update to 2.9.30
  * DNSSD backend: Always send TXT record Password=true or false,
    as iTunes 12.1.0.50 requires this
* Fri Feb  6 2015 dimstar@opensuse.org
- Add baselibs.conf to source list.
* Thu Feb  5 2015 p.drouand@gmail.com
- Update to version 2.9.29
  * Make building tests optional
- Add pkgconfig(gee-0.8) and vala build require; new upstream dependencies
* Sat Dec 21 2013 zaitor@opensuse.org
- Update to version 2.9.24:
  + Fix clang warning (bgo#711063).
  + Avoid OOB read with buggy servers (bgo#711063).
  + Use strlen() instead of hard-coding string length (bgo#711063).
- Changes from version 2.9.23:
  + Replace some assertions in dmap-gst-*-input-stream.c with error
    handling.
  + Fix daap-share.c:should_transcode().
* Tue Aug 13 2013 dimstar@opensuse.org
- Update to version 2.9.22:
  + Fix memory leak in transcoding code.
  + Remove double "end_time = ".
- Changes from version 2.9.21:
  + Add hash to DMAP records.
  + Split out dmap_hash_progressive_to_string function.
  + Add progressive MD5 hash function
- Changes from version 2.9.20:
  + Modify use of DNS_SD_CFLAGS in configure.ac.
- Changes from version 2.9.19:
  + Require GLib2 >= 2.36 and fix some compile warnings in tests.
  + Fix up dmap.h and dmap-utils.h.
  + Get to compile without warnings.
  + Fix serving large videos.
  + Fix handling of pre-transcoded video; now works with iTunes
- Changes from version 2.9.18:
  + Export dmap_mime_to_format.
  + Update transcoders and add (still broken) QuickTime transcoder.
* Wed May 15 2013 dimstar@opensuse.org
- Update to version 2.9.17:
  + Recompile Vala code with libgee-0.8.
- Changes from version 2.9.16:
  + Port to GStreamer 1.0
  + Use libgee 0.8
- Replace pkgconfig(gstreamer-plugins-base-0.10) BuildRequires with
  pkgconfig(gstreamer-plugins-base-1.0) and add explicit
  pkgconfig(gstreamer-app-1.0) BuildRequires.
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 2.9.15:
  + Change "Ignoring local service..." message from g_warning to
    g_debug
  + Use pkg-config's uninstalled feature with vapigen
* Wed Jan 18 2012 vuntz@opensuse.org
- Update to version 2.9.14:
  + Use single include for glib.
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 2.9.13:
  + Use decodebin2 instead of decodebin.
  + Make Apple dns_sd DMAPMdnsBrowser work with multiple shares.
  + Several small bug fixes.
  + Plug memory leaks.
  + Code cleanups.
  + Build fixes.
- Drop libdmapsharing-missing-header.patch: fixed upstream.
* Mon Jul  4 2011 vuntz@opensuse.org
- Update to version 2.9.12. This is a summary of the changes in the
  2.9.x branch:
  + Various API changes.
  + Attempt to serve on IPv6.
  + Fix authentication.
  + Add support for Remote version 2.
  + Add client-side DNS-SD.
  + Declare support for raop on mDNS (used by AirPortExpress).
  + Make library useful without GStreamer.
  + Vala-related clean up.
  + Several compatibility fixes.
  + Several bug fixes.
  + Code cleanups.
- Summary of changes introduced in the 2.1.x branches:
  + Add DACP support.
  + Fix serving to iTunes 10.
  + Allow two DMAP sub-protocols (e.g., DAAP and DPAP) in one
    process.
  + Several bug fixes.
- Change libsoup-devel BuildRequires to pkgconfig(libsoup-2.4).
- Add missing pkgconfig(gdk-pixbuf-2.0) BuildRequires, needed for
  cover art features.
- Remove pkgconfig(avahi-compat-libdns_sd) BuildRequires: we know
  it will not be used for dns-sd, as the standard avahi API will be
  used.
- Add libdmapsharing-missing-header.patch to fix build: add a
  missing include.
- Rename libdmapsharing2 to libdmapsharing-3_0-2 after library name
  change.
- Update descriptions.
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Sun May 22 2011 davejplater@gmail.com
- Update to stable version 2.1.9 added mDNSResponder capability.
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
- Added Url (fix for RPMLINT warning)
* Fri Sep 10 2010 dimstar@opensuse.org
- Update to version 2.0.4:
  + Fix SO_VERSION and bump version number
- Changes from version 2.0.3:
  + Add DMAPMediaKind enum
- Changes from version 2.0.2:
  + Fix serving to iTunes 10
* Mon Sep  6 2010 dimstar@opensuse.org
- Go back to version 2.0.1 (stable branch):
  + 2.1.0 is considered unstable and should not be used yet
  + Fixes the license headers in various source files, making clear
    that LGPLv2.1+ is the right license.
- Rename the shlib package to libdmapsharing1, according the soname
  of this version.
* Tue Aug 31 2010 dimstar@opensuse.org
- Initial package, version 2.1.0
